@@ -10,25 +10,25 @@ rename_dictionary = {
         '_train_config.json': {
             'inner_path': 'configs',
             "words": [{"word": '"asset_name": "', "word_format": 'str.lower', 'word_type': 'append-right',
-                       "word_pattern": '"asset_name"\s*:\s*"'},
+                       "word_pattern": r'"asset_name"\s*:\s*"'},
                       {"word": '"asset_name": \'', "word_format": 'str.lower', 'word_type': 'append-right',
-                       "word_pattern": '"asset_name"\s*:\s*\''},
+                       "word_pattern": r'"asset_name"\s*:\s*\''},
                       {"word": '\'asset_name\': \'', "word_format": 'str.lower', 'word_type': 'append-right',
-                       "word_pattern": '\'asset_name\'\s*:\s*\''},
+                       "word_pattern": r'\'asset_name\'\s*:\s*\''},
                       {"word": '\'asset_name\': "', "word_format": 'str.lower', 'word_type': 'append-right',
-                       "word_pattern": '\'asset_name\'\s*:\s*"'},
+                       "word_pattern": r'\'asset_name\'\s*:\s*"'},
                       {"word": '_config ', "word_format": 'str.lower', 'word_type': 'append-left'}]
         },
         '_forecast_config.json': {
             'inner_path': 'configs',
             "words": [{"word": '"asset_name": "', "word_format": 'str.lower', 'word_type': 'append-right',
-                       "word_pattern": '"asset_name"\s*:\s*"'},
+                       "word_pattern": r'"asset_name"\s*:\s*"'},
                       {"word": '"asset_name": \'', "word_format": 'str.lower', 'word_type': 'append-right',
-                       "word_pattern": '"asset_name"\s*:\s*\''},
+                       "word_pattern": r'"asset_name"\s*:\s*\''},
                       {"word": '\'asset_name\': \'', "word_format": 'str.lower', 'word_type': 'append-right',
-                       "word_pattern": '\'asset_name\'\s*:\s*\''},
+                       "word_pattern": r'\'asset_name\'\s*:\s*\''},
                       {"word": '\'asset_name\': "', "word_format": 'str.lower', 'word_type': 'append-right',
-                       "word_pattern": '\'asset_name\'\s*:\s*"'},
+                       "word_pattern": r'\'asset_name\'\s*:\s*"'},
                       {"word": '_config ', "word_format": 'str.lower', 'word_type': 'append-left'}]
         }
     },
@@ -47,49 +47,49 @@ rename_dictionary = {
         '_train_config.py': {
             'inner_path': 'configs',
             "words": [{"word": '"asset_name": "', "word_format": 'str.lower', 'word_type': 'append-right',
-                       "word_pattern": '"asset_name"\s*:\s*"'},
+                       "word_pattern": r'"asset_name"\s*:\s*"'},
                       {"word": '"asset_name": \'', "word_format": 'str.lower', 'word_type': 'append-right',
-                       "word_pattern": '"asset_name"\s*:\s*\''},
+                       "word_pattern": r'"asset_name"\s*:\s*\''},
                       {"word": '\'asset_name\': \'', "word_format": 'str.lower', 'word_type': 'append-right',
-                       "word_pattern": '\'asset_name\'\s*:\s*\''},
+                       "word_pattern": r'\'asset_name\'\s*:\s*\''},
                       {"word": '\'asset_name\': "', "word_format": 'str.lower', 'word_type': 'append-right',
-                       "word_pattern": '\'asset_name\'\s*:\s*"'},
+                       "word_pattern": r'\'asset_name\'\s*:\s*"'},
                       {"word": '_config ', "word_format": 'str.lower', 'word_type': 'append-left'}]
         },
         '_forecast_config.py': {
             'inner_path': 'configs',
             "words": [{"word": '"asset_name": "', "word_format": 'str.lower', 'word_type': 'append-right',
-                       "word_pattern": '"asset_name"\s*\n*\s*:\s*\n*\s*"'},
+                       "word_pattern": r'"asset_name"\s*\n*\s*:\s*\n*\s*"'},
                       {"word": '"asset_name": \'', "word_format": 'str.lower', 'word_type': 'append-right',
-                       "word_pattern": '"asset_name"\s*:\s*\''},
+                       "word_pattern": r'"asset_name"\s*:\s*\''},
                       {"word": '\'asset_name\': \'', "word_format": 'str.lower', 'word_type': 'append-right',
-                       "word_pattern": '\'asset_name\'\s*:\s*\''},
+                       "word_pattern": r'\'asset_name\'\s*:\s*\''},
                       {"word": '\'asset_name\': "', "word_format": 'str.lower', 'word_type': 'append-right',
-                       "word_pattern": '\'asset_name\'\s*:\s*"'},
+                       "word_pattern": r'\'asset_name\'\s*:\s*"'},
                       {"word": '_config ', "word_format": 'str.lower', 'word_type': 'append-left'}]
         },
         '_feature_engineering_config.py': {
             'inner_path': 'configs',
             "words": [{"word": '"asset_name": "', "word_format": 'str.lower', 'word_type': 'append-right',
-                       "word_pattern": '"asset_name"\s*\n*\s*:\s*\n*\s*"'},
+                       "word_pattern": r'"asset_name"\s*\n*\s*:\s*\n*\s*"'},
                       {"word": '"asset_name": \'', "word_format": 'str.lower', 'word_type': 'append-right',
-                       "word_pattern": '"asset_name"\s*:\s*\''},
+                       "word_pattern": r'"asset_name"\s*:\s*\''},
                       {"word": '\'asset_name\': \'', "word_format": 'str.lower', 'word_type': 'append-right',
-                       "word_pattern": '\'asset_name\'\s*:\s*\''},
+                       "word_pattern": r'\'asset_name\'\s*:\s*\''},
                       {"word": '\'asset_name\': "', "word_format": 'str.lower', 'word_type': 'append-right',
-                       "word_pattern": '\'asset_name\'\s*:\s*"'},
+                       "word_pattern": r'\'asset_name\'\s*:\s*"'},
                       {"word": '_config ', "word_format": 'str.lower', 'word_type': 'append-left'}]
         },
         '_reuse_features_and_train_config.py': {
             'inner_path': 'configs',
             "words": [{"word": '"asset_name": "', "word_format": 'str.lower', 'word_type': 'append-right',
-                       "word_pattern": '"asset_name"\s*\n*\s*:\s*\n*\s*"'},
+                       "word_pattern": r'"asset_name"\s*\n*\s*:\s*\n*\s*"'},
                       {"word": '"asset_name": \'', "word_format": 'str.lower', 'word_type': 'append-right',
-                       "word_pattern": '"asset_name"\s*:\s*\''},
+                       "word_pattern": r'"asset_name"\s*:\s*\''},
                       {"word": '\'asset_name\': \'', "word_format": 'str.lower', 'word_type': 'append-right',
-                       "word_pattern": '\'asset_name\'\s*:\s*\''},
+                       "word_pattern": r'\'asset_name\'\s*:\s*\''},
                       {"word": '\'asset_name\': "', "word_format": 'str.lower', 'word_type': 'append-right',
-                       "word_pattern": '\'asset_name\'\s*:\s*"'},
+                       "word_pattern": r'\'asset_name\'\s*:\s*"'},
                       {"word": '_config ', "word_format": 'str.lower', 'word_type': 'append-left'}]
         },
         '_feature_engineering.py': {
@@ -109,13 +109,13 @@ rename_dictionary = {
         '_train_config.json': {
             'inner_path': 'configs',
             "words": [{"word": '"asset_name": "', "word_format": 'str.lower', 'word_type': 'append-right',
-                       "word_pattern": '"asset_name"\s*:\s*"'},
+                       "word_pattern": r'"asset_name"\s*:\s*"'},
                       {"word": '_config ', "word_format": 'str.lower', 'word_type': 'append-left'}]
         },
         '_forecast_config.json': {
             'inner_path': 'configs',
             "words": [{"word": '"asset_name": "', "word_format": 'str.lower', 'word_type': 'append-right',
-                       "word_pattern": '"asset_name"\s*:\s*"'},
+                       "word_pattern": r'"asset_name"\s*:\s*"'},
                       {"word": '_config ', "word_format": 'str.lower', 'word_type': 'append-left'}]
         }
     },
@@ -129,7 +129,7 @@ rename_dictionary = {
         '_forecast_config.py': {
             'inner_path': 'configs',
             "words": [{"word": '"asset_name": "', "word_format": 'str.lower', 'word_type': 'append-right',
-                       "word_pattern": '"asset_name"\s*:\s*"'},
+                       "word_pattern": r'"asset_name"\s*:\s*"'},
                       {"word": '_config ', "word_format": 'str.lower', 'word_type': 'append-left'}]
         }
     },
@@ -143,73 +143,73 @@ rename_dictionary = {
         '_train_config.py': {
             'inner_path': 'configs',
             "words": [{"word": '"asset_name": "', "word_format": 'str.lower', 'word_type': 'append-right',
-                       "word_pattern": '"asset_name"\s*:\s*"'},
+                       "word_pattern": r'"asset_name"\s*:\s*"'},
                       {"word": '"asset_name": \'', "word_format": 'str.lower', 'word_type': 'append-right',
-                       "word_pattern": '"asset_name"\s*:\s*\''},
+                       "word_pattern": r'"asset_name"\s*:\s*\''},
                       {"word": '\'asset_name\': \'', "word_format": 'str.lower', 'word_type': 'append-right',
-                       "word_pattern": '\'asset_name\'\s*:\s*\''},
+                       "word_pattern": r'\'asset_name\'\s*:\s*\''},
                       {"word": '\'asset_name\': "', "word_format": 'str.lower', 'word_type': 'append-right',
-                       "word_pattern": '\'asset_name\'\s*:\s*"'},
+                       "word_pattern": r'\'asset_name\'\s*:\s*"'},
                       {"word": '_config ', "word_format": 'str.lower', 'word_type': 'append-left'}]
         },
         '_forecast_config.py': {
             'inner_path': 'configs',
             "words": [{"word": '"asset_name": "', "word_format": 'str.lower', 'word_type': 'append-right',
-                       "word_pattern": '"asset_name"\s*:\s*"'},
+                       "word_pattern": r'"asset_name"\s*:\s*"'},
                       {"word": '"asset_name": \'', "word_format": 'str.lower', 'word_type': 'append-right',
-                       "word_pattern": '"asset_name"\s*:\s*\''},
+                       "word_pattern": r'"asset_name"\s*:\s*\''},
                       {"word": '\'asset_name\': \'', "word_format": 'str.lower', 'word_type': 'append-right',
-                       "word_pattern": '\'asset_name\'\s*:\s*\''},
+                       "word_pattern": r'\'asset_name\'\s*:\s*\''},
                       {"word": '\'asset_name\': "', "word_format": 'str.lower', 'word_type': 'append-right',
-                       "word_pattern": '\'asset_name\'\s*:\s*"'},
+                       "word_pattern": r'\'asset_name\'\s*:\s*"'},
                       {"word": '_config ', "word_format": 'str.lower', 'word_type': 'append-left'}]
         },
         '_custom_pipeline_config.py': {
             'inner_path': 'configs',
             "words": [{"word": '"asset_name": "', "word_format": 'str.lower', 'word_type': 'append-right',
-                       "word_pattern": '"asset_name"\s*:\s*"'},
+                       "word_pattern": r'"asset_name"\s*:\s*"'},
                       {"word": '"asset_name": \'', "word_format": 'str.lower', 'word_type': 'append-right',
-                       "word_pattern": '"asset_name"\s*:\s*\''},
+                       "word_pattern": r'"asset_name"\s*:\s*\''},
                       {"word": '\'asset_name\': \'', "word_format": 'str.lower', 'word_type': 'append-right',
-                       "word_pattern": '\'asset_name\'\s*:\s*\''},
+                       "word_pattern": r'\'asset_name\'\s*:\s*\''},
                       {"word": '\'asset_name\': "', "word_format": 'str.lower', 'word_type': 'append-right',
-                       "word_pattern": '\'asset_name\'\s*:\s*"'},
+                       "word_pattern": r'\'asset_name\'\s*:\s*"'},
                       {"word": '_config ', "word_format": 'str.lower', 'word_type': 'append-left'}]
         },
         '_feature_engineering_config.py': {
             'inner_path': 'configs',
             "words": [{"word": '"asset_name": "', "word_format": 'str.lower', 'word_type': 'append-right',
-                       "word_pattern": '"asset_name"\s*:\s*"'},
+                       "word_pattern": r'"asset_name"\s*:\s*"'},
                       {"word": '"asset_name": \'', "word_format": 'str.lower', 'word_type': 'append-right',
-                       "word_pattern": '"asset_name"\s*:\s*\''},
+                       "word_pattern": r'"asset_name"\s*:\s*\''},
                       {"word": '\'asset_name\': \'', "word_format": 'str.lower', 'word_type': 'append-right',
-                       "word_pattern": '\'asset_name\'\s*:\s*\''},
+                       "word_pattern": r'\'asset_name\'\s*:\s*\''},
                       {"word": '\'asset_name\': "', "word_format": 'str.lower', 'word_type': 'append-right',
-                       "word_pattern": '\'asset_name\'\s*:\s*"'},
+                       "word_pattern": r'\'asset_name\'\s*:\s*"'},
                       {"word": '_config ', "word_format": 'str.lower', 'word_type': 'append-left'}]
         },
         '_train_step_config.py': {
             'inner_path': 'configs',
             "words": [{"word": '"asset_name": "', "word_format": 'str.lower', 'word_type': 'append-right',
-                       "word_pattern": '"asset_name"\s*:\s*"'},
+                       "word_pattern": r'"asset_name"\s*:\s*"'},
                       {"word": '"asset_name": \'', "word_format": 'str.lower', 'word_type': 'append-right',
-                       "word_pattern": '"asset_name"\s*:\s*\''},
+                       "word_pattern": r'"asset_name"\s*:\s*\''},
                       {"word": '\'asset_name\': \'', "word_format": 'str.lower', 'word_type': 'append-right',
-                       "word_pattern": '\'asset_name\'\s*:\s*\''},
+                       "word_pattern": r'\'asset_name\'\s*:\s*\''},
                       {"word": '\'asset_name\': "', "word_format": 'str.lower', 'word_type': 'append-right',
-                       "word_pattern": '\'asset_name\'\s*:\s*"'},
+                       "word_pattern": r'\'asset_name\'\s*:\s*"'},
                       {"word": '_config ', "word_format": 'str.lower', 'word_type': 'append-left'}]
         },
         '_reuse_features_and_train_config.py': {
             'inner_path': 'configs',
             "words": [{"word": '"asset_name": "', "word_format": 'str.lower', 'word_type': 'append-right',
-                       "word_pattern": '"asset_name"\s*:\s*"'},
+                       "word_pattern": r'"asset_name"\s*:\s*"'},
                       {"word": '"asset_name": \'', "word_format": 'str.lower', 'word_type': 'append-right',
-                       "word_pattern": '"asset_name"\s*:\s*\''},
+                       "word_pattern": r'"asset_name"\s*:\s*\''},
                       {"word": '\'asset_name\': \'', "word_format": 'str.lower', 'word_type': 'append-right',
-                       "word_pattern": '\'asset_name\'\s*:\s*\''},
+                       "word_pattern": r'\'asset_name\'\s*:\s*\''},
                       {"word": '\'asset_name\': "', "word_format": 'str.lower', 'word_type': 'append-right',
-                       "word_pattern": '\'asset_name\'\s*:\s*"'},
+                       "word_pattern": r'\'asset_name\'\s*:\s*"'},
                       {"word": '_config ', "word_format": 'str.lower', 'word_type': 'append-left'}]
         }
     },
@@ -226,25 +226,25 @@ rename_dictionary = {
         '_train_config.py': {
             'inner_path': 'configs',
             "words": [{"word": '"asset_name": "', "word_format": 'str.lower', 'word_type': 'append-right',
-                       "word_pattern": '"asset_name"\s*:\s*"'},
+                       "word_pattern": r'"asset_name"\s*:\s*"'},
                       {"word": '"asset_name": \'', "word_format": 'str.lower', 'word_type': 'append-right',
-                       "word_pattern": '"asset_name"\s*:\s*\''},
+                       "word_pattern": r'"asset_name"\s*:\s*\''},
                       {"word": '\'asset_name\': \'', "word_format": 'str.lower', 'word_type': 'append-right',
-                       "word_pattern": '\'asset_name\'\s*:\s*\''},
+                       "word_pattern": r'\'asset_name\'\s*:\s*\''},
                       {"word": '\'asset_name\': "', "word_format": 'str.lower', 'word_type': 'append-right',
-                       "word_pattern": '\'asset_name\'\s*:\s*"'},
+                       "word_pattern": r'\'asset_name\'\s*:\s*"'},
                       {"word": '_config ', "word_format": 'str.lower', 'word_type': 'append-left'}]
         },
         '_forecast_config.py': {
             'inner_path': 'configs',
             "words": [{"word": '"asset_name": "', "word_format": 'str.lower', 'word_type': 'append-right',
-                       "word_pattern": '"asset_name"\s*:\s*"'},
+                       "word_pattern": r'"asset_name"\s*:\s*"'},
                       {"word": '"asset_name": \'', "word_format": 'str.lower', 'word_type': 'append-right',
-                       "word_pattern": '"asset_name"\s*:\s*\''},
+                       "word_pattern": r'"asset_name"\s*:\s*\''},
                       {"word": '\'asset_name\': \'', "word_format": 'str.lower', 'word_type': 'append-right',
-                       "word_pattern": '\'asset_name\'\s*:\s*\''},
+                       "word_pattern": r'\'asset_name\'\s*:\s*\''},
                       {"word": '\'asset_name\': "', "word_format": 'str.lower', 'word_type': 'append-right',
-                       "word_pattern": '\'asset_name\'\s*:\s*"'},
+                       "word_pattern": r'\'asset_name\'\s*:\s*"'},
                       {"word": '_config ', "word_format": 'str.lower', 'word_type': 'append-left'}]
         },
         '_feature_engineering.py': {
@@ -261,25 +261,25 @@ rename_dictionary = {
         '_train_config.py': {
             'inner_path': 'configs',
             "words": [{"word": '"asset_name": "', "word_format": 'str.lower', 'word_type': 'append-right',
-                       "word_pattern": '"asset_name"\s*:\s*"'},
+                       "word_pattern": r'"asset_name"\s*:\s*"'},
                       {"word": '"asset_name": \'', "word_format": 'str.lower', 'word_type': 'append-right',
-                       "word_pattern": '"asset_name"\s*:\s*\''},
+                       "word_pattern": r'"asset_name"\s*:\s*\''},
                       {"word": '\'asset_name\': \'', "word_format": 'str.lower', 'word_type': 'append-right',
-                       "word_pattern": '\'asset_name\'\s*:\s*\''},
+                       "word_pattern": r'\'asset_name\'\s*:\s*\''},
                       {"word": '\'asset_name\': "', "word_format": 'str.lower', 'word_type': 'append-right',
-                       "word_pattern": '\'asset_name\'\s*:\s*"'},
+                       "word_pattern": r'\'asset_name\'\s*:\s*"'},
                       {"word": '_config ', "word_format": 'str.lower', 'word_type': 'append-left'}]
         },
         '_forecast_config.py': {
             'inner_path': 'configs',
             "words": [{"word": '"asset_name": "', "word_format": 'str.lower', 'word_type': 'append-right',
-                       "word_pattern": '"asset_name"\s*:\s*"'},
+                       "word_pattern": r'"asset_name"\s*:\s*"'},
                       {"word": '"asset_name": \'', "word_format": 'str.lower', 'word_type': 'append-right',
-                       "word_pattern": '"asset_name"\s*:\s*\''},
+                       "word_pattern": r'"asset_name"\s*:\s*\''},
                       {"word": '\'asset_name\': \'', "word_format": 'str.lower', 'word_type': 'append-right',
-                       "word_pattern": '\'asset_name\'\s*:\s*\''},
+                       "word_pattern": r'\'asset_name\'\s*:\s*\''},
                       {"word": '\'asset_name\': "', "word_format": 'str.lower', 'word_type': 'append-right',
-                       "word_pattern": '\'asset_name\'\s*:\s*"'},
+                       "word_pattern": r'\'asset_name\'\s*:\s*"'},
                       {"word": '_config ', "word_format": 'str.lower', 'word_type': 'append-left'}]
         },
     },
@@ -293,37 +293,37 @@ rename_dictionary = {
         '_train_config.py': {
             'inner_path': 'configs',
             "words": [{"word": '"asset_name": "', "word_format": 'str.lower', 'word_type': 'append-right',
-                       "word_pattern": '"asset_name"\s*:\s*"'},
+                       "word_pattern": r'"asset_name"\s*:\s*"'},
                       {"word": '"asset_name": \'', "word_format": 'str.lower', 'word_type': 'append-right',
-                       "word_pattern": '"asset_name"\s*:\s*\''},
+                       "word_pattern": r'"asset_name"\s*:\s*\''},
                       {"word": '\'asset_name\': \'', "word_format": 'str.lower', 'word_type': 'append-right',
-                       "word_pattern": '\'asset_name\'\s*:\s*\''},
+                       "word_pattern": r'\'asset_name\'\s*:\s*\''},
                       {"word": '\'asset_name\': "', "word_format": 'str.lower', 'word_type': 'append-right',
-                       "word_pattern": '\'asset_name\'\s*:\s*"'},
+                       "word_pattern": r'\'asset_name\'\s*:\s*"'},
                       {"word": '_config ', "word_format": 'str.lower', 'word_type': 'append-left'}]
         },
         '_forecast_config.py': {
             'inner_path': 'configs',
             "words": [{"word": '"asset_name": "', "word_format": 'str.lower', 'word_type': 'append-right',
-                       "word_pattern": '"asset_name"\s*:\s*"'},
+                       "word_pattern": r'"asset_name"\s*:\s*"'},
                       {"word": '"asset_name": \'', "word_format": 'str.lower', 'word_type': 'append-right',
-                       "word_pattern": '"asset_name"\s*:\s*\''},
+                       "word_pattern": r'"asset_name"\s*:\s*\''},
                       {"word": '\'asset_name\': \'', "word_format": 'str.lower', 'word_type': 'append-right',
-                       "word_pattern": '\'asset_name\'\s*:\s*\''},
+                       "word_pattern": r'\'asset_name\'\s*:\s*\''},
                       {"word": '\'asset_name\': "', "word_format": 'str.lower', 'word_type': 'append-right',
-                       "word_pattern": '\'asset_name\'\s*:\s*"'},
+                       "word_pattern": r'\'asset_name\'\s*:\s*"'},
                       {"word": '_config ', "word_format": 'str.lower', 'word_type': 'append-left'}]
         },
         '_prediction_accuracy_config.json': {
             'inner_path': 'configs',
             "words": [{"word": '"asset_name": "', "word_format": 'str.lower', 'word_type': 'append-right',
-                       "word_pattern": '"asset_name"\s*:\s*"'},
+                       "word_pattern": r'"asset_name"\s*:\s*"'},
                       {"word": '"asset_name": \'', "word_format": 'str.lower', 'word_type': 'append-right',
-                       "word_pattern": '"asset_name"\s*:\s*\''},
+                       "word_pattern": r'"asset_name"\s*:\s*\''},
                       {"word": '\'asset_name\': \'', "word_format": 'str.lower', 'word_type': 'append-right',
-                       "word_pattern": '\'asset_name\'\s*:\s*\''},
+                       "word_pattern": r'\'asset_name\'\s*:\s*\''},
                       {"word": '\'asset_name\': "', "word_format": 'str.lower', 'word_type': 'append-right',
-                       "word_pattern": '\'asset_name\'\s*:\s*"'},
+                       "word_pattern": r'\'asset_name\'\s*:\s*"'},
                       {"word": '_config ', "word_format": 'str.lower', 'word_type': 'append-left'}]
         }
     }
